<?php

declare(strict_types = 1);

namespace Drupal\group_media_library_extra_groupmedia\Plugin\GroupMediaLibraryExtra\MediaItemsSource;

use Drupal\group\Plugin\GroupContentEnablerManagerInterface;
use Drupal\group_media_library_extra\MediaItemsSource\MediaItemsSourceBase;
use Drupal\group_media_library_extra\MediaItemsSource\MediaItemsSourceInterface;
use Drupal\media_library\MediaLibraryState;
use Drupal\views\Plugin\views\query\QueryPluginBase;
use Drupal\views\Plugin\ViewsHandlerManager;
use Drupal\views\ViewExecutable;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Media items without group plugin instance.
 *
 * @GroupMediaLibraryMediaItemsSource(
 *   id = "media_items_without_group",
 *   label = @Translation("Media items without group"),
 *   description = @Translation("Use the media items the do not belong to any group."),
 *   contexts = {
 *     "no_group",
 *   },
 * )
 */
class MediaItemsWithoutGroup extends MediaItemsSourceBase implements MediaItemsSourceInterface {

  /**
   * Group enabler plugin manager.
   *
   * @var \Drupal\group\Plugin\GroupContentEnablerManagerInterface
   */
  protected $groupEnabler;

  /**
   * MediaItemsSourceBase constructor.
   *
   * @param array $configuration
   *   Plugin configuration.
   * @param string $plugin_id
   *   Plugin id.
   * @param mixed $plugin_definition
   *   Plugin definition.
   * @param \Drupal\views\Plugin\ViewsHandlerManager $join_manager
   *   The views plugin join manager.
   * @param \Drupal\group\Plugin\GroupContentEnablerManagerInterface $groupEnablerManager
   *   Group content enabler plugin manager.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ViewsHandlerManager $join_manager, GroupContentEnablerManagerInterface $groupEnablerManager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $join_manager);
    $this->groupEnabler = $groupEnablerManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): self {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('plugin.manager.views.join'),
      $container->get('plugin.manager.group_content_enabler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function query(ViewExecutable $view, QueryPluginBase $query): void {
    // This plugin filter out the media items that belong to group.
    $state = MediaLibraryState::fromRequest($view->getRequest());
    $group_content_type_map = $this->groupEnabler
      ->getPluginGroupContentTypeMap();

    $group_content_instance_hashed_ids = $group_content_type_map['group_media:' . $state->getSelectedTypeId()] ?? NULL;
    if ($group_content_instance_hashed_ids) {
      $definition = [
        'table' => 'group_content_field_data',
        'field' => 'entity_id',
        'left_table' => 'media_field_data',
        'left_field' => 'mid',
        'type' => 'LEFT',
        'extra' => [
          ['field' => 'type', 'value' => $group_content_instance_hashed_ids],
        ],
      ];

      $query->addRelationship('grfd', $this->joinManager->createInstance('standard', $definition), 'media');
      $query->addWhereExpression(0, 'grfd.gid IS NULL');
    }
  }

}
